
[Testing a local Anchor](#Test Header)
[Testing a remote Anchor](project.md#Test Header)

[My Section](my-section.md "Testing this Title")

[My Section](my-section.md#Anchor-test "Test Title")

![Alt Text](puppy "Test Title")

[[#Section Heading]]

[[#Section Heading|Title]]


## External Links, containing schemes
[External Link](https://www.example.com)

[External Link](http://www.example.com)

[External Link](mailto://person@example.com)

[External Link](dig://example.com)

[External Link](ftp://example.com)

[External Link](ssh://example.com)

[External Link w/ Title](https://www.example.com "LINK TITLE")

[External link no scheme](www.example.com) (broken)



MD Links:

[My Section](my-section) [My Section Link 2](my-section.md) [My Section Link 3](my-section.md#anchor "Test")


WikiLinks:

[[My Section]] [[My Section|My Section 2]] [[My Section|My Section 3]]

Both:

[[My Section|Wiki Link]] [My Section 2](my-section) [[Fence Blocks]]
